Description: Minor spelling fixes:
 recieved  -> received
 Portugese -> Portuguese
 Potugese  -> Portuguese
 splitted  -> split
Author: Markus Wanner <markus@bluegap.ch>, Bas Couwenberg <sebastic@debian.org>
Forwarded: https://trac.osgeo.org/postgis/ticket/3289
Applied-Upstream: https://trac.osgeo.org/postgis/changeset/14113
                  https://trac.osgeo.org/postgis/changeset/14115

--- a/liblwgeom/lwout_wkt.c
+++ b/liblwgeom/lwout_wkt.c
@@ -323,7 +323,7 @@ static void lwcompound_to_wkt_sb(const L
 		}
 		else
 		{
-			lwerror("lwcompound_to_wkt_sb: Unknown type recieved %d - %s", type, lwtype_name(type));
+			lwerror("lwcompound_to_wkt_sb: Unknown type received %d - %s", type, lwtype_name(type));
 		}
 	}
 	stringbuffer_append(sb, ")");
@@ -370,7 +370,7 @@ static void lwcurvepoly_to_wkt_sb(const
 			lwcompound_to_wkt_sb((LWCOMPOUND*)cpoly->rings[i], sb, precision, variant );
 			break;
 		default:
-			lwerror("lwcurvepoly_to_wkt_sb: Unknown type recieved %d - %s", type, lwtype_name(type));
+			lwerror("lwcurvepoly_to_wkt_sb: Unknown type received %d - %s", type, lwtype_name(type));
 		}
 	}
 	stringbuffer_append(sb, ")");
@@ -418,7 +418,7 @@ static void lwmcurve_to_wkt_sb(const LWM
 			lwcompound_to_wkt_sb((LWCOMPOUND*)mcurv->geoms[i], sb, precision, variant );
 			break;
 		default:
-			lwerror("lwmcurve_to_wkt_sb: Unknown type recieved %d - %s", type, lwtype_name(type));
+			lwerror("lwmcurve_to_wkt_sb: Unknown type received %d - %s", type, lwtype_name(type));
 		}
 	}
 	stringbuffer_append(sb, ")");
@@ -462,7 +462,7 @@ static void lwmsurface_to_wkt_sb(const L
 			lwcurvepoly_to_wkt_sb((LWCURVEPOLY*)msurf->geoms[i], sb, precision, variant);
 			break;
 		default:
-			lwerror("lwmsurface_to_wkt_sb: Unknown type recieved %d - %s", type, lwtype_name(type));
+			lwerror("lwmsurface_to_wkt_sb: Unknown type received %d - %s", type, lwtype_name(type));
 		}
 	}
 	stringbuffer_append(sb, ")");
--- a/loader/shpcommon.h
+++ b/loader/shpcommon.h
@@ -68,8 +68,8 @@ static code_page_entry code_pages[] = {
     {0x1F, 852, "Czech OEM", "CP852",""},
     {0x22, 852, "Hungarian OEM", "CP852",""},
     {0x23, 852, "Polish OEM", "CP852",""},
-    {0x24, 860, "Portugese OEM", "CP860",""},
-    {0x25, 850, "Potugese OEM*", "CP850",""},
+    {0x24, 860, "Portuguese OEM", "CP860",""},
+    {0x25, 850, "Portuguese OEM*", "CP850",""},
     {0x26, 866, "Russian OEM", "WINDOWS-866","WIN866"},
     {0x37, 850, "English OEM (U.S.)*", "CP850",""},
     {0x40, 852, "Romanian OEM", "CP852",""},
--- a/ChangeLog
+++ b/ChangeLog
@@ -34232,7 +34232,7 @@
 	  topology/test/regress/st_addedgenewfaces.sql,
 	  topology/test/regress/st_addedgenewfaces_expected:
 	  topology.ST_AddEdgeNewFaces: do not needlessly replace face of
-	  holes found in a face splitted by the newly added edge. Regress
+	  holes found in a face split by the newly added edge. Regress
 	  test it. [RT-SIGTA].
 
 2011-05-27 08:34  Sandro Santilli <strk@keybit.net>
@@ -46710,7 +46710,7 @@
 	  doc/xsl/postgis_comments.sql.xsl,
 	  doc/xsl/postgis_gardentest.sql.xsl,
 	  doc/xsl/postgis_gardentest_subset.sql.xsl: Switch to reference
-	  splitted files. Add references entities. Use postgis.xml rather
+	  split files. Add references entities. Use postgis.xml rather
 	  than reference.xml in doc/xsl/* files. Add template rule in
 	  doc/xsl/* to only use /book/chapter[@id='reference'].
 
@@ -65920,7 +65920,7 @@
 	  are handled on a minimun-diff basis, making it easier to
 	  understand
 	  the differences and to modify the code. Also, diffs have been
-	  splitted between pgsql < 73 and >= 73.
+	  split between pgsql < 73 and >= 73.
 	  Added reduced-parameters wrappers to both functions.
 
 2004-03-22 08:18  Sandro Santilli <strk@keybit.net>
--- a/doc/extras_topology.xml
+++ b/doc/extras_topology.xml
@@ -2351,7 +2351,7 @@ of an edge.
 
 	<para>
 If any edge crossing the node is found either an exception is raised or
-the edge is splitted, depending on the <varname>allowEdgeSplitting</varname>
+the edge is split, depending on the <varname>allowEdgeSplitting</varname>
 parameter value.
 	</para>
 
--- a/doc/po/es/extras_topology.xml.po
+++ b/doc/po/es/extras_topology.xml.po
@@ -2883,7 +2883,7 @@ msgstr ""
 #, no-c-format
 msgid ""
 "If any edge crossing the node is found either an exception is raised or the "
-"edge is splitted, depending on the <varname>allowEdgeSplitting</varname> "
+"edge is split, depending on the <varname>allowEdgeSplitting</varname> "
 "parameter value."
 msgstr ""
 
--- a/doc/po/fr/extras_topology.xml.po
+++ b/doc/po/fr/extras_topology.xml.po
@@ -3122,7 +3122,7 @@ msgstr ""
 #, no-c-format
 msgid ""
 "If any edge crossing the node is found either an exception is raised or the "
-"edge is splitted, depending on the <varname>allowEdgeSplitting</varname> "
+"edge is split, depending on the <varname>allowEdgeSplitting</varname> "
 "parameter value."
 msgstr ""
 
--- a/doc/po/it_IT/extras_topology.xml.po
+++ b/doc/po/it_IT/extras_topology.xml.po
@@ -2882,7 +2882,7 @@ msgstr ""
 #, no-c-format
 msgid ""
 "If any edge crossing the node is found either an exception is raised or the "
-"edge is splitted, depending on the <varname>allowEdgeSplitting</varname> "
+"edge is split, depending on the <varname>allowEdgeSplitting</varname> "
 "parameter value."
 msgstr ""
 
--- a/doc/po/ko_KR/extras_topology.xml.po
+++ b/doc/po/ko_KR/extras_topology.xml.po
@@ -2883,7 +2883,7 @@ msgstr ""
 #, no-c-format
 msgid ""
 "If any edge crossing the node is found either an exception is raised or the "
-"edge is splitted, depending on the <varname>allowEdgeSplitting</varname> "
+"edge is split, depending on the <varname>allowEdgeSplitting</varname> "
 "parameter value."
 msgstr ""
 
--- a/doc/po/pl/extras_topology.xml.po
+++ b/doc/po/pl/extras_topology.xml.po
@@ -3151,7 +3151,7 @@ msgstr ""
 #, no-c-format
 msgid ""
 "If any edge crossing the node is found either an exception is raised or the "
-"edge is splitted, depending on the <varname>allowEdgeSplitting</varname> "
+"edge is split, depending on the <varname>allowEdgeSplitting</varname> "
 "parameter value."
 msgstr ""
 
--- a/doc/po/pt_BR/extras_topology.xml.po
+++ b/doc/po/pt_BR/extras_topology.xml.po
@@ -2882,7 +2882,7 @@ msgstr ""
 #, no-c-format
 msgid ""
 "If any edge crossing the node is found either an exception is raised or the "
-"edge is splitted, depending on the <varname>allowEdgeSplitting</varname> "
+"edge is split, depending on the <varname>allowEdgeSplitting</varname> "
 "parameter value."
 msgstr ""
 
--- a/doc/po/templates/extras_topology.xml.pot
+++ b/doc/po/templates/extras_topology.xml.pot
@@ -2215,7 +2215,7 @@ msgstr ""
 #. Tag: para
 #: extras_topology.xml:2040
 #, no-c-format
-msgid "If any edge crossing the node is found either an exception is raised or the edge is splitted, depending on the <varname>allowEdgeSplitting</varname> parameter value."
+msgid "If any edge crossing the node is found either an exception is raised or the edge is split, depending on the <varname>allowEdgeSplitting</varname> parameter value."
 msgstr ""
 
 #. Tag: para
--- a/liblwgeom/liblwgeom_topo.h
+++ b/liblwgeom/liblwgeom_topo.h
@@ -380,7 +380,7 @@ typedef struct LWT_BE_CALLBACKS_T {
    * Update TopoGeometry objects after an edge split event
    *
    * @param topo the topology to act upon
-   * @param split_edge identifier of the edge that was splitted.
+   * @param split_edge identifier of the edge that was split.
    * @param new_edge1 identifier of the first new edge that was created
    *        as a result of edge splitting.
    * @param new_edge2 identifier of the second new edge that was created
@@ -517,7 +517,7 @@ typedef struct LWT_BE_CALLBACKS_T {
    * Update TopoGeometry objects after a face split event
    *
    * @param topo the topology to act upon
-   * @param split_face identifier of the face that was splitted.
+   * @param split_face identifier of the face that was split.
    * @param new_face1 identifier of the first new face that was created
    *        as a result of face splitting.
    * @param new_face2 identifier of the second new face that was created
--- a/topology/sql/sqlmm.sql.in
+++ b/topology/sql/sqlmm.sql.in
@@ -366,7 +366,7 @@ BEGIN
   END IF;
 
 #ifdef POSTGIS_TOPOLOGY_DEBUG
-  RAISE DEBUG 'Edge % splitted face %', anedge, oface;
+  RAISE DEBUG 'Edge % split face %', anedge, oface;
 #endif
 
   sql := 'WITH ids as ( select row_number() over () as seq, edge '

--- a/liblwgeom/lwgeom_topo.c
+++ b/liblwgeom/lwgeom_topo.c
@@ -1096,7 +1096,7 @@ lwt_ModEdgeSplit( LWT_TOPOLOGY* topo, LW
   } else if ( ret == 0 ) {
     _lwt_release_edges(oldedge, 1);
     lwcollection_free(split_col);
-    lwerror("Edge being splitted (%d) disappeared during operations?", oldedge->edge_id);
+    lwerror("Edge being split (%d) disappeared during operations?", oldedge->edge_id);
     return -1;
   } else if ( ret > 1 ) {
     _lwt_release_edges(oldedge, 1);
@@ -1763,7 +1763,7 @@ _lwt_AddFaceSplit( LWT_TOPOLOGY* topo,
     }
   }
 
-  LWDEBUGF(1, "Edge %" LWTFMT_ELEMID " splitted face %" LWTFMT_ELEMID " (mbr_only:%d)",
+  LWDEBUGF(1, "Edge %" LWTFMT_ELEMID " split face %" LWTFMT_ELEMID " (mbr_only:%d)",
            sedge, face, mbr_only);
 
   /* Construct a polygon using edges of the ring */
@@ -1862,7 +1862,7 @@ _lwt_AddFaceSplit( LWT_TOPOLOGY* topo,
 
   if ( face == 0 )
   {
     /* Edge splitted the universe face */
     if ( ! isccw )
     {
       lwpoly_free(shell);
@@ -5199,7 +5199,7 @@ _lwt_GetEqualEdge( LWT_TOPOLOGY *topo, L
 }
 
 /*
  * Add a pre-noded pre-splitted line edge. Used by lwt_AddLine
  * Return edge id, 0 if none added (empty edge), -1 on error
  */
 static LWT_ELEMID
@@ -5521,7 +5521,7 @@ lwt_AddLine(LWT_TOPOLOGY* topo, LWLINE*
           /* lwgeom_split(noded, inodes); */
       lwgeom_free(noded);
       noded = tmp;
-      LWDEBUGG(1, noded, "Node-splitted");
+      LWDEBUGG(1, noded, "Node-split");
 
       /* will not release the geoms array */
       lwcollection_release(col);
@@ -5559,7 +5559,7 @@ lwt_AddLine(LWT_TOPOLOGY* topo, LWLINE*
     ngeoms = 1;
   }
 
-  LWDEBUGF(1, "Line was splitted into %d edges", ngeoms);
+  LWDEBUGF(1, "Line was split into %d edges", ngeoms);
 
   /* TODO: refactor to first add all nodes (re-snapping edges if
    * needed) and then check all edges for existing already
@@ -1862,7 +1862,7 @@ _lwt_AddFaceSplit( LWT_TOPOLOGY* topo,
   if ( face == 0 )
   {
-    /* Edge splitted the universe face */
+    /* Edge split the universe face */
     if ( ! isccw )
     {
@@ -5199,7 +5199,7 @@ _lwt_GetEqualEdge( LWT_TOPOLOGY *topo, L
 
 /*
- * Add a pre-noded pre-splitted line edge. Used by lwt_AddLine
+ * Add a pre-noded pre-split line edge. Used by lwt_AddLine
  * Return edge id, 0 if none added (empty edge), -1 on error
  */